@@ -1,21 +1,23 @@
 # Copyright 2021 Google LLC
-
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-
+#
 #     https://www.apache.org/licenses/LICENSE-2.0
-
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .helpers import make_connection, dataset_polymorphic
-import google.cloud.bigquery.dataset
 import pytest
 
+import google.cloud.bigquery.dataset
+from google.cloud.bigquery.retry import DEFAULT_TIMEOUT
+from .helpers import make_connection, dataset_polymorphic
+
 
 @dataset_polymorphic
 def test_list_tables_empty_w_timeout(
@@ -89,7 +91,7 @@ def test_list_tables_defaults(make_dataset, get_reference, client, PROJECT, DS_I
     assert token == TOKEN
 
     conn.api_request.assert_called_once_with(
-        method="GET", path="/%s" % PATH, query_params={}, timeout=None
+        method="GET", path="/%s" % PATH, query_params={}, timeout=DEFAULT_TIMEOUT
     )
 
 
@@ -150,7 +152,7 @@ def test_list_tables_explicit(client, PROJECT, DS_ID):
         method="GET",
         path="/%s" % PATH,
         query_params={"maxResults": 3, "pageToken": TOKEN},
-        timeout=None,
+        timeout=DEFAULT_TIMEOUT,
     )
 
 
